==> haskell-text-rope-0.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-3o9dslmtje1Dz1yj93o2Vj
key:                  text-rope-0.3-3o9dslmtje1Dz1yj93o2Vj
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  f16c4958559faf78c7d95c0678f3bc52
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-3o9dslmtje1Dz1yj93o2Vj
depends:
    base-4.16.4.0 deepseq-1.4.6.1 text-1.2.5.0
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-rope-0.3-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-78tjK1vSrjs5cWsiVOBg3d
key:                  text-rope-0.3-78tjK1vSrjs5cWsiVOBg3d
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  80724d969bc52a0cb346bebf3fc7aa74
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-78tjK1vSrjs5cWsiVOBg3d
depends:
    base-4.16.4.0 deepseq-1.4.6.1 text-1.2.5.0
    vector-0.13.1.0-IOJlwkRydAuH1Lkdw56w5r

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
